==> dagster-fivetran-0.23.2rc3.tar.gz: dagster-fivetran-0.23.2rc3/setup.py <==
from pathlib import Path
from typing import Dict

from setuptools import find_packages, setup


def get_version() -> str:
    version: Dict[str, str] = {}
    with open(Path(__file__).parent / "dagster_fivetran/version.py", encoding="utf8") as fp:
        exec(fp.read(), version)

    return version["__version__"]


ver = get_version()
# dont pin dev installs to avoid pip dep resolver issues
pin = "" if ver == "1!0+dev" else f"=={ver}"
setup(
    name="dagster-fivetran",
    version=ver,
    author="Dagster Labs",
    author_email="hello@dagsterlabs.com",
    license="Apache-2.0",
    description="Package for integrating Fivetran with Dagster.",
    url="https://github.com/dagster-io/dagster/tree/master/python_modules/libraries/dagster-fivetran",
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    packages=find_packages(exclude=["dagster_fivetran_tests*"]),
    python_requires=">=3.8,<3.13",
    install_requires=["dagster==1.7.2rc3"],
    zip_safe=False,
    entry_points={
        "console_scripts": [
            "dagster-fivetran = dagster_fivetran.cli:main",
        ]
    },
    extras_require={
        "managed": [
            "dagster-managed-elements==0.23.2rc3",
        ],
    },
)

==> dagster-fivetran-0.23.3.tar.gz: dagster-fivetran-0.23.3/setup.py <==
from pathlib import Path
from typing import Dict

from setuptools import find_packages, setup


def get_version() -> str:
    version: Dict[str, str] = {}
    with open(Path(__file__).parent / "dagster_fivetran/version.py", encoding="utf8") as fp:
        exec(fp.read(), version)

    return version["__version__"]


ver = get_version()
# dont pin dev installs to avoid pip dep resolver issues
pin = "" if ver == "1!0+dev" else f"=={ver}"
setup(
    name="dagster-fivetran",
    version=ver,
    author="Dagster Labs",
    author_email="hello@dagsterlabs.com",
    license="Apache-2.0",
    description="Package for integrating Fivetran with Dagster.",
    url="https://github.com/dagster-io/dagster/tree/master/python_modules/libraries/dagster-fivetran",
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    packages=find_packages(exclude=["dagster_fivetran_tests*"]),
    python_requires=">=3.8,<3.13",
    install_requires=["dagster==1.7.3"],
    zip_safe=False,
    entry_points={
        "console_scripts": [
            "dagster-fivetran = dagster_fivetran.cli:main",
        ]
    },
    extras_require={
        "managed": [
            "dagster-managed-elements==0.23.3",
        ],
    },
)
